@@ -3,7 +3,7 @@
 #' @param data A list of sf objects containing the datasets for which likelihoods need to be constructed.
 #' @param formula A list of formulas to add to the likelihoods.
 #' @param family A list of vectors containing the families within each dataset.
-#' @param mesh An inla.mesh object.
+#' @param mesh An \code{fm_mesh_2d} object.
 #' @param ips Integration points used.
 #' @param paresp The response variable name for the presence absence datasets.
 #' @param ntrialsvar The trials variable name for the presence absence datasets.
@@ -59,7 +59,7 @@ makeLhoods <- function(data, formula, family, mesh, ips,
             if (as.character(formula[[dataset]][[species]][[process]][['LHS']])[2] == paresp) Ntrials <- Ntrialsvar[[1]]
             
             else 
-              if (!is.na(Ntrialsvar[[2]])) Ntrials <- Ntrialsvar[[2]]
+              if (!any(is.na(Ntrialsvar[[2]]))) Ntrials <- Ntrialsvar[[2]]
               else Ntrials <- 1
             
           } else Ntrials <- 1
@@ -99,21 +99,24 @@ makeLhoods <- function(data, formula, family, mesh, ips,
         
         }
         }
-          
+
+        # bru_like_list will use the like-tag for list names; inlabru >= 2.12.0
+        if (is.null(names(data[[dataset]])[species])) nameGive <- names(data)[[dataset]]
+        else nameGive <- names(data[[dataset]])[species]
+        
+        like_name <- paste0(nameGive, '_', sub(' .*', '', as.character(formula[[dataset]][[species]][[process]][['LHS']])[2]))
+        
         Likelihoods[[Likindex]] <- inlabru::like(formula = formula[[dataset]][[species]][[process]][['LHS']], ## but obs change these in function call
                                                  include = formula[[dataset]][[species]][[process]][['RHS']],
                                                  data = data[[dataset]][[species]], 
                                                  Ntrials = Ntrials,
-                                                 mesh = mesh,
                                                  ips = IPS,
                                                  domain = list(geometry = mesh),
                                                  samplers = samplers[[names(data)[[dataset]]]],
-                                                 family = family[[dataset]][process])
+                                                 family = family[[dataset]][process],
+                                                 tag = like_name)
         
-        if (is.null(names(data[[dataset]])[species])) nameGive <- names(data)[[dataset]]
-        else nameGive <- names(data[[dataset]])[species]
-        
-        names(Likelihoods)[[Likindex]] <- paste0(nameGive, '_', sub(' .*', '', as.character(formula[[dataset]][[species]][[process]][['LHS']])[2]))
+        names(Likelihoods)[[Likindex]] <- like_name
         
       } 
       
