@@ -11,7 +11,7 @@ setClass('modMarks_predict')
 #' @param object A \code{modMarks} object.
 #' @param data Data containing points of the map with which to predict on. May be \code{NULL} if one of \code{mesh} or \code{mask} is \code{NULL}.
 #' @param formula Formula to predict. May be \code{NULL} if other arguments: \code{covariates}, \code{spatial}, \code{intercepts} are not \code{NULL}.
-#' @param mesh An \code{inla.mesh} object.
+#' @param mesh An \code{fm_mesh_2d} object.
 #' @param mask A mask of the study background. Defaults to \code{NULL}.
 #' @param covariates Name of covariates to predict.
 #' @param spatial Logical: include spatial effects in prediction. Defaults to \code{FALSE}.
@@ -65,7 +65,7 @@ predict.modMarks <- function(object, data = NULL, formula = NULL, mesh = NULL,
                              marks = NULL, bias = FALSE, biasnames = NULL, predictor = FALSE,
                              fun = 'linear', ...) {
   
-  if (is.null(data) & is.null(mesh)) stop("Either data covering the entire study region or an inla.mesh object is required.")
+  if (is.null(data) & is.null(mesh)) stop("Either data covering the entire study region or an fm_mesh_2d object is required.")
   
   ## if non-null biasfields ## if no bias fields in stop: if biasnames not in biasfields stop
   if (bias && spatial) stop('Please choose one of bias and spatial.')
@@ -140,10 +140,10 @@ predict.modMarks <- function(object, data = NULL, formula = NULL, mesh = NULL,
     
     if (!is.null(mask)) {
       
-      data <- inlabru::fm_pixels(mesh, mask = mask)
+      data <- fmesher::fm_pixels(mesh, mask = mask)
       
     }   
-    else data <- inlabru::fm_int(mesh)
+    else data <- fmesher::fm_int(mesh)
   }
   
   if (!any(names(data) %in% object$spatCovs$name)) {
@@ -193,7 +193,7 @@ predict.modMarks <- function(object, data = NULL, formula = NULL, mesh = NULL,
       time_data <- data.frame(seq_len(max(numeric_time)))
       names(time_data) <- time_variable
       
-      data <- inlabru::fm_cprod(data, data.frame(time_data))
+      data <- fmesher::fm_cprod(data, data.frame(time_data))
       data$.__plot__index__ <- data[[time_variable]]
       
     }
@@ -428,4 +428,4 @@ plot.modMarks_predict <- function(x,
   }
   
   
-}
\ No newline at end of file
+}
