@@ -272,11 +272,10 @@ specifyMarks <- R6::R6Class(classname = 'specifyMarks', lock_objects = FALSE, cl
     
     if (!is.null(private$temporalName)) {
       
-      if (shareModel) private$Components <- c(private$Components, paste0('sharedBias_biasField(main = geometry, model = sharedBias_bias_field, group =', private$temporalName,', ngroup = ', length(unique(unlist(private$temporalVars))),', control.group = ', temporalModel,')'))
-      
       temporalModel <- deparse1(temporalModel)
       
-      private$Components <- c(private$Components, paste0(datasetNames ,'_biasField(main = geometry, model = ', datasetNames, '_bias_field, group = ', private$temporalName, ', ngroup = ', length(unique(unlist(private$temporalVars))),', control.group = ', temporalModel,')'))
+      if (shareModel) private$Components <- c(private$Components, paste0('sharedBias_biasField(main = geometry, model = sharedBias_bias_field, group =', private$temporalName,', ngroup = ', length(unique(unlist(private$temporalVars))),', control.group = ', temporalModel,')'))
+      else private$Components <- c(private$Components, paste0(datasetNames ,'_biasField(main = geometry, model = ', datasetNames, '_bias_field, group = ', private$temporalName, ', ngroup = ', length(unique(unlist(private$temporalVars))),', control.group = ', temporalModel,')'))
       
       
     }
@@ -1120,7 +1119,7 @@ specifyMarks <- R6::R6Class(classname = 'specifyMarks', lock_objects = FALSE, cl
   #' @param datasetName Name of the dataset for the samplers.
   #' @param Samplers A \code{Spatial*} object representing the integration domain.
   #' 
-  #' @example
+  #' @examples
   #' \dontrun{
   #'  if (requireNamespace('INLA')) {
   #'    
@@ -1159,7 +1158,7 @@ specifyMarks <- R6::R6Class(classname = 'specifyMarks', lock_objects = FALSE, cl
   #' @param copyModel List of model specifications given to the hyper parameters for the \code{"copy"} model. Defaults to \code{list(beta = list(fixed = FALSE))}.
   #' @param copyBias List of model specifications given to the hyper parameters for the \code{"copy"} bias model. Defaults to \code{list(beta = list(fixed = FALSE))}.
   #' @return An updated component list. 
-  #' @example
+  #' @examples
   #' \dontrun{
   #'  if (requireNamespace('INLA')) {
   #'    
@@ -1294,7 +1293,7 @@ specifyMarks$set('private', 'originalNames', NULL)
 #' @param data The points of the model.
 #' @param coordinates A vector of length 2 containing the names of the coordinates.
 #' @param projection The projection of the data.
-#' @param Inlamesh An inla.mesh object.
+#' @param Inlamesh An \code{fm_mesh_2d} object.
 #' @param speciesindependent Independent species effects.
 #' @param initialnames The names of the datasets if data is passed through intModel.
 #' @param responsecounts The name of the response variable for the count data.
@@ -1331,7 +1330,7 @@ specifyMarks$set('public', 'initialize',  function(data,coordinates,
   if (missing(projection)) stop('projection needs to be given.')
   if (missing(Inlamesh)) stop('Mesh needs to be given.')
   
-  if (!inherits(Inlamesh, 'inla.mesh')) stop('Mesh needs to be an inla.mesh object.')
+  if (!inherits(Inlamesh, 'fm_mesh_2d')) stop('Mesh needs to be an fm_mesh_2d object.')
   
   if (inherits(projection, 'CRS')) projection <- as(projection, 'character')
   else if (!inherits(projection, 'character')) stop('Projection needs to be a character object.')
@@ -1367,8 +1366,8 @@ specifyMarks$set('public', 'initialize',  function(data,coordinates,
   
   if (is.null(ips)) {
     
-    if (!is.null(boundary)) ips <- st_transform(inlabru::fm_int(samplers = boundary, domain = Inlamesh), projection)
-    else ips <- st_transform(inlabru::fm_int(domain = Inlamesh), projection)
+    if (!is.null(boundary)) ips <- st_transform(fmesher::fm_int(samplers = boundary, domain = Inlamesh), projection)
+    else ips <- st_transform(fmesher::fm_int(domain = Inlamesh), projection)
     
     
   }
@@ -1378,7 +1377,7 @@ specifyMarks$set('public', 'initialize',  function(data,coordinates,
   st_geometry(ips) <- 'geometry'
   
   if (!is.null(spatial)) {
-    if (spatial == 'correlate') ips <- fm_cprod(ips, data = data.frame(._dataset_index_var_. = 1:length(initialnames)))
+    if (spatial == 'correlate') ips <- fmesher::fm_cprod(ips, data = data.frame(._dataset_index_var_. = 1:length(initialnames)))
   }  
   private$IPS <- ips
   
@@ -1923,4 +1922,4 @@ specifyMarks$set('public', 'spatialFields', list(sharedField = list(),
                                             datasetFields = list(),
                                             speciesFields = list(),
                                             markFields = list(),
-                                            biasFields = list()))
\ No newline at end of file
+                                            biasFields = list()))
