@@ -38,10 +38,10 @@ spIn <- c('bird', 'dog', 'fish')
 
 
 if (requireNamespace("INLA")) {
-  mesh <<- INLA::inla.mesh.2d(boundary = INLA::inla.sp2segment(SpatialPoly), 
-                              max.edge = 2, crs = inlabru::fm_crs(projection))
+  mesh <<- fmesher::fm_mesh_2d_inla(boundary = fmesher::fm_as_segm(SpatialPoly), 
+                              max.edge = 2, crs = fmesher::fm_crs(projection))
   #iPoints <<- inlabru::ipoints(samplers = SpatialPoly, domain = mesh)
-  iPoints <<- inlabru::fm_int(samplers = SpatialPoly, domain = mesh)
+  iPoints <<- fmesher::fm_int(samplers = SpatialPoly, domain = mesh)
   
 }
 
@@ -198,7 +198,8 @@ test_that('specifySpecies initialize works as expected.', {
                      speciesname = speciesName,
                      ips = iPoints, copymodel = copyModel,
                      spatial = 'shared', temporal = temporalName, 
-                     intercepts = TRUE, temporalmodel = temporalModel), 'Mesh needs to be an inla.mesh object.')
+                     intercepts = TRUE, temporalmodel = temporalModel),
+               'Mesh needs to be an fm_mesh_2d object.')
   
   #Change speciesSpatial to shared
   checkShared <<- specifySpecies$new(data = list(PO, PA, Pcount),
